==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/storage/kotlin/inputs/ManagementPolicyVersionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storage.kotlin.inputs

import com.pulumi.azurenative.storage.inputs.ManagementPolicyVersionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Management policy action for blob version.
 * @property delete The function to delete the blob version
 * @property tierToArchive The function to tier blob version to archive storage.
 * @property tierToCold The function to tier blobs to cold storage.
 * @property tierToCool The function to tier blob version to cool storage.
 * @property tierToHot The function to tier blobs to hot storage. This action can only be used with Premium Block Blob Storage Accounts
 */
public data class ManagementPolicyVersionArgs(
    public val delete: Output<DateAfterCreationArgs>? = null,
    public val tierToArchive: Output<DateAfterCreationArgs>? = null,
    public val tierToCold: Output<DateAfterCreationArgs>? = null,
    public val tierToCool: Output<DateAfterCreationArgs>? = null,
    public val tierToHot: Output<DateAfterCreationArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storage.inputs.ManagementPolicyVersionArgs> {
    override fun toJava(): com.pulumi.azurenative.storage.inputs.ManagementPolicyVersionArgs =
        com.pulumi.azurenative.storage.inputs.ManagementPolicyVersionArgs.builder()
            .delete(delete?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .tierToArchive(tierToArchive?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .tierToCold(tierToCold?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .tierToCool(tierToCool?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .tierToHot(tierToHot?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ManagementPolicyVersionArgs].
 */
@PulumiTagMarker
public class ManagementPolicyVersionArgsBuilder internal constructor() {
    private var delete: Output<DateAfterCreationArgs>? = null

    private var tierToArchive: Output<DateAfterCreationArgs>? = null

    private var tierToCold: Output<DateAfterCreationArgs>? = null

    private var tierToCool: Output<DateAfterCreationArgs>? = null

    private var tierToHot: Output<DateAfterCreationArgs>? = null

    /**
     * @param value The function to delete the blob version
     */
    @JvmName("caahcfrlvmkqcpvk")
    public suspend fun delete(`value`: Output<DateAfterCreationArgs>) {
        this.delete = value
    }

    /**
     * @param value The function to tier blob version to archive storage.
     */
    @JvmName("uqkomqtiuwvsatsq")
    public suspend fun tierToArchive(`value`: Output<DateAfterCreationArgs>) {
        this.tierToArchive = value
    }

    /**
     * @param value The function to tier blobs to cold storage.
     */
    @JvmName("tvdyvmlmsappihae")
    public suspend fun tierToCold(`value`: Output<DateAfterCreationArgs>) {
        this.tierToCold = value
    }

    /**
     * @param value The function to tier blob version to cool storage.
     */
    @JvmName("njvcmuuftaqanjfm")
    public suspend fun tierToCool(`value`: Output<DateAfterCreationArgs>) {
        this.tierToCool = value
    }

    /**
     * @param value The function to tier blobs to hot storage. This action can only be used with Premium Block Blob Storage Accounts
     */
    @JvmName("ixxilsnbymugohjd")
    public suspend fun tierToHot(`value`: Output<DateAfterCreationArgs>) {
        this.tierToHot = value
    }

    /**
     * @param value The function to delete the blob version
     */
    @JvmName("lajmoscmbwkakupp")
    public suspend fun delete(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.delete = mapped
    }

    /**
     * @param argument The function to delete the blob version
     */
    @JvmName("wmybnphaudrcsgvc")
    public suspend fun delete(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.delete = mapped
    }

    /**
     * @param value The function to tier blob version to archive storage.
     */
    @JvmName("cipmiyhaaugyxnnq")
    public suspend fun tierToArchive(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tierToArchive = mapped
    }

    /**
     * @param argument The function to tier blob version to archive storage.
     */
    @JvmName("nxxeouubrmgdvrcc")
    public suspend fun tierToArchive(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tierToArchive = mapped
    }

    /**
     * @param value The function to tier blobs to cold storage.
     */
    @JvmName("xmrhughndxcygldy")
    public suspend fun tierToCold(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tierToCold = mapped
    }

    /**
     * @param argument The function to tier blobs to cold storage.
     */
    @JvmName("crkdtohmltbsjvho")
    public suspend fun tierToCold(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tierToCold = mapped
    }

    /**
     * @param value The function to tier blob version to cool storage.
     */
    @JvmName("pilhsogjtxlyqgtw")
    public suspend fun tierToCool(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tierToCool = mapped
    }

    /**
     * @param argument The function to tier blob version to cool storage.
     */
    @JvmName("ndxbwakpmyeohppa")
    public suspend fun tierToCool(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tierToCool = mapped
    }

    /**
     * @param value The function to tier blobs to hot storage. This action can only be used with Premium Block Blob Storage Accounts
     */
    @JvmName("kmhhcgohitvbmobi")
    public suspend fun tierToHot(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tierToHot = mapped
    }

    /**
     * @param argument The function to tier blobs to hot storage. This action can only be used with Premium Block Blob Storage Accounts
     */
    @JvmName("bayjidtacybdqwfy")
    public suspend fun tierToHot(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tierToHot = mapped
    }

    internal fun build(): ManagementPolicyVersionArgs = ManagementPolicyVersionArgs(
        delete = delete,
        tierToArchive = tierToArchive,
        tierToCold = tierToCold,
        tierToCool = tierToCool,
        tierToHot = tierToHot,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/storage/kotlin/inputs/ManagementPolicyVersionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storage.kotlin.inputs

import com.pulumi.azurenative.storage.inputs.ManagementPolicyVersionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Management policy action for blob version.
 * @property delete The function to delete the blob version
 * @property tierToArchive The function to tier blob version to archive storage.
 * @property tierToCold The function to tier blobs to cold storage.
 * @property tierToCool The function to tier blob version to cool storage.
 * @property tierToHot The function to tier blobs to hot storage. This action can only be used with Premium Block Blob Storage Accounts
 */
public data class ManagementPolicyVersionArgs(
    public val delete: Output<DateAfterCreationArgs>? = null,
    public val tierToArchive: Output<DateAfterCreationArgs>? = null,
    public val tierToCold: Output<DateAfterCreationArgs>? = null,
    public val tierToCool: Output<DateAfterCreationArgs>? = null,
    public val tierToHot: Output<DateAfterCreationArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storage.inputs.ManagementPolicyVersionArgs> {
    override fun toJava(): com.pulumi.azurenative.storage.inputs.ManagementPolicyVersionArgs =
        com.pulumi.azurenative.storage.inputs.ManagementPolicyVersionArgs.builder()
            .delete(delete?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .tierToArchive(tierToArchive?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .tierToCold(tierToCold?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .tierToCool(tierToCool?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .tierToHot(tierToHot?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ManagementPolicyVersionArgs].
 */
@PulumiTagMarker
public class ManagementPolicyVersionArgsBuilder internal constructor() {
    private var delete: Output<DateAfterCreationArgs>? = null

    private var tierToArchive: Output<DateAfterCreationArgs>? = null

    private var tierToCold: Output<DateAfterCreationArgs>? = null

    private var tierToCool: Output<DateAfterCreationArgs>? = null

    private var tierToHot: Output<DateAfterCreationArgs>? = null

    /**
     * @param value The function to delete the blob version
     */
    @JvmName("vuriewrjocwuyhor")
    public suspend fun delete(`value`: Output<DateAfterCreationArgs>) {
        this.delete = value
    }

    /**
     * @param value The function to tier blob version to archive storage.
     */
    @JvmName("cfqjuhnvnkjebcgt")
    public suspend fun tierToArchive(`value`: Output<DateAfterCreationArgs>) {
        this.tierToArchive = value
    }

    /**
     * @param value The function to tier blobs to cold storage.
     */
    @JvmName("ofiymuiibtvvegus")
    public suspend fun tierToCold(`value`: Output<DateAfterCreationArgs>) {
        this.tierToCold = value
    }

    /**
     * @param value The function to tier blob version to cool storage.
     */
    @JvmName("fjygjfheomsbnfap")
    public suspend fun tierToCool(`value`: Output<DateAfterCreationArgs>) {
        this.tierToCool = value
    }

    /**
     * @param value The function to tier blobs to hot storage. This action can only be used with Premium Block Blob Storage Accounts
     */
    @JvmName("jkpnxcdklpmtngkl")
    public suspend fun tierToHot(`value`: Output<DateAfterCreationArgs>) {
        this.tierToHot = value
    }

    /**
     * @param value The function to delete the blob version
     */
    @JvmName("addjhnvywwieuaeu")
    public suspend fun delete(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.delete = mapped
    }

    /**
     * @param argument The function to delete the blob version
     */
    @JvmName("paqgphoejgyannjt")
    public suspend fun delete(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.delete = mapped
    }

    /**
     * @param value The function to tier blob version to archive storage.
     */
    @JvmName("trcwwwkdgmiakwmf")
    public suspend fun tierToArchive(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tierToArchive = mapped
    }

    /**
     * @param argument The function to tier blob version to archive storage.
     */
    @JvmName("lkxxqrwthkerklil")
    public suspend fun tierToArchive(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tierToArchive = mapped
    }

    /**
     * @param value The function to tier blobs to cold storage.
     */
    @JvmName("hmqepxwpqfdlpnno")
    public suspend fun tierToCold(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tierToCold = mapped
    }

    /**
     * @param argument The function to tier blobs to cold storage.
     */
    @JvmName("juueuxrinoiiiaag")
    public suspend fun tierToCold(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tierToCold = mapped
    }

    /**
     * @param value The function to tier blob version to cool storage.
     */
    @JvmName("hhscwyoqfomlpgob")
    public suspend fun tierToCool(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tierToCool = mapped
    }

    /**
     * @param argument The function to tier blob version to cool storage.
     */
    @JvmName("iplfshwbwxbqqjsw")
    public suspend fun tierToCool(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tierToCool = mapped
    }

    /**
     * @param value The function to tier blobs to hot storage. This action can only be used with Premium Block Blob Storage Accounts
     */
    @JvmName("vvxomhkyllqrfklw")
    public suspend fun tierToHot(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tierToHot = mapped
    }

    /**
     * @param argument The function to tier blobs to hot storage. This action can only be used with Premium Block Blob Storage Accounts
     */
    @JvmName("fjffoacsaxmunpoy")
    public suspend fun tierToHot(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tierToHot = mapped
    }

    internal fun build(): ManagementPolicyVersionArgs = ManagementPolicyVersionArgs(
        delete = delete,
        tierToArchive = tierToArchive,
        tierToCold = tierToCold,
        tierToCool = tierToCool,
        tierToHot = tierToHot,
    )
}
